import { ITranslatorOptions, TypeTData } from './types';
declare global {
    interface Window {
        Translator: typeof Translator;
        newTranslations: TypeTData;
    }
}
/**
 * Translator is the main entry point for i18n-babel.
 * It can be used to initialize the i18n-babel system.
 * It also gives access to the translation API through `Translator.t` function.
 */
export declare class Translator {
    static instance: Translator;
    private tDonwloader;
    private language;
    private opts;
    private availableLangs;
    private observers;
    private static defaultOptions;
    private ilEsc;
    private irEsc;
    private constructor();
    /**
     * Gets the static instance of Translator
     * @returns an instance to the Translator class
     */
    static getInstance(): Translator;
    /**
     * Checks whether if Translator has been initialized
     * @returns true if the instance has been already initialized
     */
    static isInitialized(): boolean;
    /**
     * Initializes the Translator system. It keeps only one instance per runtime
     * and it can be called as many times as desired. It will always return the
     * same instance.
     *
     * When called twice with different options, options will be overriden.
     *
     * @param options translator options
     * @returns a singleton instance to Translator
     */
    static init(options?: ITranslatorOptions): Translator;
    private setupOptions;
    private refreshMutationObservers;
    /**
     * Attach TManager to all elements with the `dataAttribute` attribute, traversing shadow dom's
     */
    private processDataAttributes;
    private startDOMObserver;
    private disconnectObservers;
    static setLocalValuesAllowed(isLocalValuesAllowed?: boolean): void;
    setLocalValuesAllowed(isLocalValuesAllowed?: boolean): void;
    /**
    * Translates a text, returns the text itself if no translation is found.
    * @param originalText text to translate
    * @param tData Interpolation parameters
    * @param lang Translation language
    * @returns Translated text
    */
    static t(originalText: string, tData?: TypeTData, lang?: string): Promise<string>;
    /**
     * Translates a text, returns the text itself if no translation is found.
     * @param originalText text to translate
     * @param tData Interpolation parameters
     * @param lang Translation language
     * @returns Translated text
     */
    t(originalText: string, tData?: TypeTData, lang?: string): Promise<string>;
    /**
    * *Función para uso interno*. Recorre las keys del JSON para comprobar si coinciden con el RegExp (p.ej) : `${key}`,
    * si coinciden sustituye la palabra por el valor encontrado en el JSON (p.ej) : `${nombre}` por `Toni`
    * @param text Texto a interpolar
    * @param data Json que contiene los paramatros del componente (p.ej) : `{ nombre: 'Toni', edad: 25 }`
    * @returns El texto interpolado
    */
    private interpolate;
    /**
     * Guess the language. First look at the `lang` cookie.
     * If it's not available, it looks for the language in these places (in this order of precedence):
     *
     * - options.userLanguage
     * - navigator.userLanguage
     * - options.defaultLanguage
     *
     * @param isSkipCookie does not read from cookie
     * @param resetCookie saves the favorite language to `lang` cookie
     * @returns 2 letters favorite language
     */
    static guessLanguage(isSkipCookie?: boolean, resetCookie?: boolean): string;
    /**
     * Guess the language. First look at the `lang` cookie.
     * If it's not available, it looks for the language in these places (in this order of precedence):
     *
     * - options.userLanguage
     * - navigator.userLanguage
     * - options.defaultLanguage
     *
     * @param isSkipCookie does not read from cookie
     * @param resetCookie saves the favorite language to `lang` cookie
     * @returns 2 letters favorite language
     */
    guessLanguage(isSkipCookie?: boolean, resetCookie?: boolean): string;
    /**
     * Guesses the language (see `guessLanguage()`) and filters it with `availableLangs`.
     * If the language is not present in `availableLangs` the `options.defaultLanguage` will be returned.
     *
     * @returns 2 letters default language
     */
    static getDefaultLanguage(): string;
    /**
     * Guesses the language (see `guessLanguage()`) and filters it with `availableLangs`.
     * If the language is not present in `availableLangs` the `options.defaultLanguage` will be returned.
     *
     * @returns 2 letters default language
     */
    getDefaultLanguage(): string;
    /**
     * Gets current language of the application.
     * The language will be one of the availableLangs or the defaultOne
     * @param lang new language
     * @returns current language
     */
    static getCurrentLanguage(): string;
    /**
     * Gets current language of the application.
     * The language will be one of the availableLangs or the defaultOne
     * @param lang new language
     * @returns current language
     */
    getCurrentLanguage(): string;
    /**
     * Changes the language of the application.
     * Must be one of availableLangs otherwise the favorite language will be selected.
     * @param lang new language
     * @returns new language
     */
    static setLanguage(lang: string): string;
    /**
     * Changes the language of the application.
     * Must be one of availableLangs otherwise the favorite language will be selected.
     * @param lang new language
     * @returns new language
     */
    setLanguage(lang: string): string;
    /**
     * Clears the translations cache and tries to download again the translations.
     */
    static cacheClear(): void;
    /**
     * Clears the translations cache and tries to download again the translations.
     */
    cacheClear(): void;
    /**
     * Get missing translations. The array gets updated when a new missing translation is found.
     * @returns an array of strings with missing translations
     */
    static getMissingTranslations(): any[] | TypeTData;
    /**
     * Get missing translations. The array gets updated when a new missing translation is found.
     * @returns an array of strings with missing translations
     */
    getMissingTranslations(): any[] | TypeTData;
}
